import React from 'react';
import classnames from 'classnames';
import { parseMetadata } from '@highlight-ui/utils-commons';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

function getInitials(name, fallback) {
    if (fallback === void 0) { fallback = '?'; }
    if (!name || typeof name !== 'string')
        return fallback;
    return name
        .split(' ')
        .filter(Boolean) // filter out the empty strings
        .slice(0, 2) // We take only two words of the name for the initial
        .map(function (s) { return s[0].toUpperCase(); }) // Convert the first digit of those two strings to uppercase
        .join('');
}

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = "@import url(\"https://fonts.googleapis.com/css2?family=IBM+Plex+Mono:wght@400;700&display=swap\");\n@import url(\"https://fonts.googleapis.com/css2?family=Open+Sans:ital,wght@0,300;0,400;0,600;0,700;1,300;1,400;1,600;1,700&display=swap\");\n.Avatar-module__J4amZaj5__v1-0-2 {\n  border: 2px solid #fff;\n  border-radius: 50%;\n  height: 46px;\n  width: 46px;\n}\n\n.Avatar-module__3Da-ZGwP__v1-0-2 {\n  transition: transform 0.2s ease-in-out;\n}\n.Avatar-module__3Da-ZGwP__v1-0-2:hover {\n  transform: scale(1.1);\n}\n\n.Avatar-module__2KFwChSW__v1-0-2 {\n  display: inline-block;\n  position: relative;\n}\n.Avatar-module__2KFwChSW__v1-0-2:hover {\n  cursor: pointer;\n}";
var styles = {"avatar":"Avatar-module__J4amZaj5__v1-0-2","avatarAnimated":"Avatar-module__3Da-ZGwP__v1-0-2","avatarContainer":"Avatar-module__2KFwChSW__v1-0-2"};
styleInject(css_248z);

var AVATAR_SERVICE_BASE_URL = 'https://avatar-service-platform.personio.de';
var DEFAULT_AVATAR_SIZE = 46;
function getAvatarChild(src, name, imageClassname) {
    var initials = getInitials(name);
    return (React.createElement("img", { className: classnames(styles.avatar, imageClassname), src: src ||
            AVATAR_SERVICE_BASE_URL + "/" + initials + "?size=" + DEFAULT_AVATAR_SIZE, alt: initials }));
}
function AvatarWithRef(_a, ref) {
    var _b;
    var _c = _a.src, src = _c === void 0 ? '' : _c, _d = _a.name, name = _d === void 0 ? '' : _d, url = _a.url, containerClassname = _a.containerClassname, _e = _a.animate, animate = _e === void 0 ? false : _e, _f = _a.imageClassname, imageClassname = _f === void 0 ? '' : _f, children = _a.children, metadata = _a.metadata, restProps = __rest(_a, ["src", "name", "url", "containerClassname", "animate", "imageClassname", "children", "metadata"]);
    return (React.createElement("a", __assign({}, restProps, parseMetadata(metadata), { href: url, className: classnames(styles.avatarContainer, (_b = {},
            _b[styles.avatarAnimated] = animate,
            _b), containerClassname), ref: ref }), children && typeof children === 'function'
        ? children(function () { return getAvatarChild(src, name, imageClassname); })
        : getAvatarChild(src, name, imageClassname)));
}
AvatarWithRef.displayName = 'Avatar';
var Avatar = React.forwardRef(AvatarWithRef);

export default Avatar;
//# sourceMappingURL=index.js.map
